@@ -15,7 +15,7 @@ use Lemonldap::NG::Common::Apache::Session::Serialize::JSON;
 use Lemonldap::NG::Common::Apache::Session::Store;
 use Lemonldap::NG::Common::Apache::Session::Lock;
 
-our $VERSION = '1.9.5';
+our $VERSION = '1.9.99_02';
 
 sub _load {
     my ( $backend, $func ) = @_;
@@ -36,7 +36,7 @@ sub populate {
         $self = $self->$backend(@_);
     }
     if ( $backend =~
-/^Apache::Session::(?:(?:Postgre|Redi)s|(?:Oracl|Sybas)e|(?:My|No)SQL|F(?:ile|lex)|Cassandra|LDAP)/
+/^Apache::Session::(?:(?:Postgre|Redi)s|S(?:QLite3|ybase)|(?:My|No)SQL|F(?:ile|lex)|Cassandra|Oracle|LDAP)/
         and !$self->{args}->{useStorable} )
     {
         $self->{serialize} =
@@ -89,7 +89,9 @@ sub searchOn {
         sub {
             my $entry = shift;
             my $id    = shift;
-            return undef unless ( $entry->{$selectField} eq $value );
+            return undef
+              unless ( $entry->{$selectField}
+                and $entry->{$selectField} eq $value );
             if (@fields) {
                 $res{$id}->{$_} = $entry->{$_} foreach (@fields);
             }
