@@ -8,7 +8,7 @@ package Lemonldap::NG::Common::Apache::Session::SOAP;
 use strict;
 use SOAP::Lite;
 
-our $VERSION = '1.9.1';
+our $VERSION = '1.9.99_02';
 
 #parameter proxy Url of SOAP service
 #parameter proxyOptions SOAP::Lite options
@@ -126,7 +126,7 @@ sub _connect {
     if ( $self->{proxyOptions} ) {
         push @args, %{ $self->{proxyOptions} };
     }
-    $self->{ns} ||= 'urn:Lemonldap/NG/Common/CGI/SOAPService';
+    $self->{ns} ||= 'urn:Lemonldap/NG/Common/PSGI/SOAPService';
     return $self->{service} = SOAP::Lite->ns( $self->{ns} )->proxy(@args);
 }
 
@@ -235,8 +235,12 @@ sub get_key_from_all_sessions() {
     }
     die('proxy is required') unless ( $self->{proxy} );
     ( $user, $password ) = ( $args->{User}, $args->{Password} );
+
+    # Get token before query
+    my $token = Lemonldap::NG::Handler::Main->tsv->{cipher}
+      ->decrypt( $self->_soapCall('getCipheredToken') );
     if ( ref($data) eq 'CODE' ) {
-        my $r = $self->_soapCall( "get_key_from_all_sessions", $args );
+        my $r = $self->_soapCall( "get_key_from_all_sessions", $token );
         my $res;
         if ($r) {
             foreach my $k ( keys %$r ) {
@@ -246,7 +250,7 @@ sub get_key_from_all_sessions() {
         }
     }
     else {
-        return $self->_soapCall( "get_key_from_all_sessions", $args, $data );
+        return $self->_soapCall( "get_key_from_all_sessions", $token, $data );
     }
 }
 
@@ -286,7 +290,7 @@ access to Lemonldap::NG Web-SSO sessions via SOAP.
   __PACKAGE__->init ({
          globalStorage => 'Lemonldap::NG::Common::Apache::Session::SOAP',
          globalStorageOptions => {
-                 proxy => 'http://auth.example.com/index.pl/sessions',
+                 proxy => 'http://auth.example.com/sessions',
                  proxyOptions => {
                      timeout => 5,
                  },
@@ -309,7 +313,7 @@ access to Lemonldap::NG Web-SSO sessions via SOAP.
   my $portal = new Lemonldap::NG::Portal::SharedConf (
          globalStorage => 'Lemonldap::NG::Common::Apache::Session::SOAP',
          globalStorageOptions => {
-                 proxy => 'http://auth.example.com/index.pl/sessions',
+                 proxy => 'http://auth.example.com/sessions',
                  proxyOptions => {
                      timeout => 5,
                  },
@@ -364,7 +368,7 @@ C<>SOAP::Transport::HTTP::Client::get_basic_credentials>:
   __PACKAGE__->init ( {
       globalStorage => 'Lemonldap::NG::Common::Apache::Session::SOAP',
       globalStorageOptions => {
-                proxy => 'http://auth.example.com/index.pl/sessions',
+                proxy => 'http://auth.example.com/sessions',
                 User     => 'http-user',
                 Password => 'pass',
       },
@@ -386,7 +390,7 @@ set environment variables.
   __PACKAGE__->init ( {
       globalStorage => 'Lemonldap::NG::Common::Apache::Session::SOAP',
       globalStorageOptions => {
-                proxy => 'https://auth.example.com/index.pl/sessions',
+                proxy => 'https://auth.example.com/sessions',
       },
   } );
 
@@ -398,15 +402,11 @@ L<Lemonldap::NG::Manager>, L<Lemonldap::NG::Common::Conf::SOAP>,
 L<Lemonldap::NG::Handler>, L<Lemonldap::NG::Portal>,
 L<http://lemonldap-ng.org/>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 =over
 
-=item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
-
-=item François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
-
-=item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+=item LemonLDAP::NG team L<http://lemonldap-ng.org/team>
 
 =back
 
@@ -422,15 +422,7 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-=over
-
-=item Copyright (C) 2008-2013 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
-
-=item Copyright (C) 2012 by François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
-
-=item Copyright (C) 2010-2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
-
-=back
+See COPYING file for details.
 
 This library is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
