@@ -1,9 +1,9 @@
 package Lemonldap::NG::Common::Apache::Session::Serialize::JSON;
 
 use strict;
-use JSON;
+use JSON qw(to_json from_json);
 
-our $VERSION = '1.9.5';
+our $VERSION = '1.9.99_02';
 
 sub serialize {
     my $session = shift;
