@@ -12,6 +12,10 @@ use utf8;
 no strict 'refs';
 use Lemonldap::NG::Common::Conf::Constants;    #inherits
 
+# Import compacter
+use Lemonldap::NG::Common::Conf::Compact;
+*compactConf = \&Lemonldap::NG::Common::Conf::Compact::compactConf;
+
 # TODO: don't import this big file, use a proxy
 use Lemonldap::NG::Common::Conf::DefaultValues;    #inherits
 use Lemonldap::NG::Common::Crypto
@@ -23,7 +27,7 @@ use Config::IniFiles;
 #inherits Lemonldap::NG::Common::Conf::SOAP
 #inherits Lemonldap::NG::Common::Conf::LDAP
 
-our $VERSION = '1.9.1';
+our $VERSION = '1.9.99_02';
 our $msg     = '';
 our $iniObj;
 
@@ -43,7 +47,7 @@ BEGIN {
 # - { Type => "File", dirName => "/path/to/conf/dir/" },
 # - { Type => "DBI", dbiChain => "DBI:mysql:database=lemonldap-ng;host=1.2.3.4",
 # dbiUser => "user", dbiPassword => "password" },
-# - { Type => "SOAP", proxy => "https://auth.example.com/index.pl/config" },
+# - { Type => "SOAP", proxy => "https://auth.example.com/config" },
 # - { Type => "LDAP", ldapServer => "ldap://localhost", ldapConfBranch => "ou=conf,ou=applications,dc=example,dc=com",
 #  ldapBindDN => "cn=manager,dc=example,dc=com", ldapBindPassword => "secret"},
 #
@@ -79,7 +83,7 @@ sub new {
         unless ( $self->{type} =~ /^[\w:]+$/ ) {
             $msg .= "Error: configStorage: type is not well formed.\n";
         }
-        $self->{type} = "Lemonldap::NG::Common::Conf::$self->{type}"
+        $self->{type} = "Lemonldap::NG::Common::Conf::Backends::$self->{type}"
           unless $self->{type} =~ /^Lemonldap::/;
         eval "require $self->{type}";
         if ($@) {
@@ -169,6 +173,9 @@ sub getConf {
         unless ( ref( $self->{refLocalStorage} ) ) {
             $msg .= "Get remote configuration (localStorage unavailable).\n";
             $r = $self->getDBConf($args);
+            return undef unless ( $r->{cfgNum} );
+            $self->setDefault( $r, $args->{localPrm} );
+            $self->compactConf($r);
         }
         else {
             eval { $r = $self->{refLocalStorage}->get('conf') }
@@ -187,38 +194,8 @@ sub getConf {
                 $r = $self->getDBConf($args);
                 return undef unless ( $r->{cfgNum} );
 
-                # TODO: default values may not be set here
-                unless ( $args->{raw} ) {
-
-                    # Adapt some values before storing in local cache
-                    # Get default values
-                    my $defaultValues =
-                      Lemonldap::NG::Common::Conf::DefaultValues
-                      ->defaultValues();
-
-                    foreach my $k ( keys %$defaultValues ) {
-                        $r->{$k} //= $defaultValues->{$k};
-                    }
-                }
-
-                # Convert old option useXForwardedForIP into trustedProxies
-                if ( defined $r->{useXForwardedForIP}
-                    and $r->{useXForwardedForIP} == 1 )
-                {
-                    $r->{trustedProxies} = '*';
-                    delete $r->{useXForwardedForIP};
-                }
-
-                # Force Choice backend
-                if ( $r->{authentication} eq "Choice" ) {
-                    $r->{userDB}     = "Choice";
-                    $r->{passwordDB} = "Choice";
-                }
-
-            # Some parameters expect key name (example), not variable ($example)
-                if ( defined $r->{whatToTrace} ) {
-                    $r->{whatToTrace} =~ s/^\$//;
-                }
+                $self->setDefault( $r, $args->{localPrm} );
+                $self->compactConf($r);
 
                 # Store modified configuration in cache
                 $self->setLocalConf($r)
@@ -230,6 +207,7 @@ sub getConf {
 
         # Create cipher object
         unless ( $args->{raw} ) {
+
             eval {
                 $r->{cipher} = Lemonldap::NG::Common::Crypto->new( $r->{key} );
             };
@@ -243,6 +221,42 @@ sub getConf {
     }
 }
 
+# Set default values
+sub setDefault {
+    my ( $self, $conf, $localPrm ) = @_;
+    my $defaultValues =
+      Lemonldap::NG::Common::Conf::DefaultValues->defaultValues();
+    if ( $localPrm and %$localPrm ) {
+        foreach my $k ( keys %$localPrm ) {
+            $conf->{$k} = $localPrm->{$k};
+        }
+    }
+    foreach my $k ( keys %$defaultValues ) {
+        $conf->{$k} //= $defaultValues->{$k};
+    }
+
+    # Convert old option useXForwardedForIP into trustedProxies
+    if ( defined $conf->{useXForwardedForIP}
+        and $conf->{useXForwardedForIP} == 1 )
+    {
+        $conf->{trustedProxies} = '*';
+        delete $conf->{useXForwardedForIP};
+    }
+
+    # Force Choice backend
+    if ( $conf->{authentication} eq "Choice" ) {
+        $conf->{userDB}     = "Choice";
+        $conf->{passwordDB} = "Choice";
+    }
+
+    # Some parameters expect key name (example), not variable ($example)
+    if ( defined $conf->{whatToTrace} ) {
+        $conf->{whatToTrace} =~ s/^\$//;
+    }
+
+    return $conf;
+}
+
 ## @method hashRef getLocalConf(string section, string file, int loaddefault)
 # Get configuration from local file
 #
@@ -459,6 +473,8 @@ Web-SSO configuration.
 =head1 SYNOPSIS
 
   use Lemonldap::NG::Common::Conf;
+  # Lemonldap::NG::Common::Conf reads loacl configuration from lemonldap-ng.ini.
+  # Parameters can be overridden in a hash:
   my $confAccess = new Lemonldap::NG::Common::Conf(
               {
                   type=>'File',
@@ -475,69 +491,39 @@ Web-SSO configuration.
                   },
               },
     ) or die "Unable to build Lemonldap::NG::Common::Conf, see Apache logs";
+  # Next, get global configuration. Note that local parameters override global
+  # ones
   my $config = $confAccess->getConf();
 
 =head1 DESCRIPTION
 
-Lemonldap::NG::Common::Conf provides a simple interface to access to
-Lemonldap::NG Web-SSO configuration. It is used by L<Lemonldap::NG::Handler>,
-L<Lemonldap::NG::Portal> and L<Lemonldap::NG::Manager>.
+Lemonldap::NG::Common::Conf is used by all Lemonldap::NG packages to access to
+local/global configuration.
 
 =head2 SUBROUTINES
 
 =over
 
-=item * B<new> (constructor): it takes different arguments depending on the
-chosen type. Examples:
+=item * B<new> (constructor)
+
+It can takes any Lemonldap::NG parameter to override configuration. The
+'confFile' parameter can be used to override lemonldap-ng.ini path.
+Examples:
 
 =over
 
-=item * B<File>:
+=item * B<Set another lemonldap-ng.ini file>
   $confAccess = new Lemonldap::NG::Common::Conf(
-                {
-                type    => 'File',
-                dirName => '/var/lib/lemonldap-ng/',
-                });
-
-=item * B<DBI>:
+                  { confFile => '/opt/lemonldap-ng.ini' } );
+=item * B<Override global storage>:
   $confAccess = new Lemonldap::NG::Common::Conf(
-                {
-                type        => 'DBI',
-                dbiChain    => 'DBI:mysql:database=lemonldap-ng;host=1.2.3.4',
-                dbiUser     => 'lemonldap'
-                dbiPassword => 'pass'
-                dbiTable    => 'lmConfig',
-                });
-
-=item * B<SOAP>:
-  $confAccess = new Lemonldap::NG::Common::Conf(
-                {
-                type         => 'SOAP',
-                proxy        => 'http://auth.example.com/index.pl/config',
-                proxyOptions => {
-                                timeout => 5,
-                                },
-                });
-
-SOAP configuration access is a sort of proxy: the portal is configured to use
-the real session storage type (DBI or File for example). See HTML documentation
-for more.
-
-=item * B<LDAP>:
-  $confAccess = new Lemonldap::NG::Common::Conf(
-                {
-                type             => 'LDAP',
-                ldapServer       => 'ldap://localhost',
-                ldapConfBranch   => 'ou=conf,ou=applications,dc=example,dc=com',
-                ldapBindDN       => 'cn=manager,dc=example,dc=com",
-                ldapBindPassword => 'secret'
-                });
+                  {
+                    type    => 'File',
+                    dirName => '/var/lib/lemonldap-ng/conf',
+                   });
 
 =back
 
-WARNING: You have to use the same storage type on all Lemonldap::NG parts in
-the same server.
-
 =item * B<getConf>: returns a hash reference to the configuration. it takes
 a hash reference as first argument containing 2 optional parameters:
 
@@ -558,27 +544,20 @@ getConf returns all (C<select * from lmConfig>).
 
 =head1 SEE ALSO
 
-L<Lemonldap::NG::Handler>, L<Lemonldap::NG::Portal>,
 L<http://lemonldap-ng.org/>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 =over
 
-=item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
-
-=item François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
-
-=item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
-
-=item Sandro Cazzaniga, E<lt>cazzaniga.sandro@gmail.comE<gt>
+=item LemonLDAP::NG team L<http://lemonldap-ng.org/team>
 
 =back
 
 =head1 BUG REPORT
 
 Use OW2 system to report bug or ask for features:
-L<https://gitlab.ow2.org/lemonldap-ng/lemonldap-ng/issues>
+L<http://jira.ow2.org>
 
 =head1 DOWNLOAD
 
@@ -587,17 +566,7 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-=over
-
-=item Copyright (C) 2008-2016 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
-
-=item Copyright (C) 2012 by Sandro Cazzaniga, E<lt>cazzaniga.sandro@gmail.comE<gt>
-
-=item Copyright (C) 2012 by François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
-
-=item Copyright (C) 2009-2016 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
-
-=back
+See COPYING file for details.
 
 This library is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
