@@ -4,7 +4,7 @@ use JSON;
 use Mouse;
 use Lemonldap::NG::Common::PSGI;
 
-our $VERSION = '1.9.13';
+our $VERSION = '1.9.99_02';
 
 has iniFile => ( is => 'ro', isa => 'Str' );
 
@@ -122,42 +122,39 @@ sub _del {
 sub jsonResponse {
     my ( $self, $path, $query ) = @_;
     my $res = $self->_get( $path, $query )
-      or die "Manager lib has refused my get, aborting";
+      or die "PSGI lib has refused my get, aborting";
     unless ( $res->[0] == 200 ) {
         require Data::Dumper;
         print STDERR "Result dump :\n" . Data::Dumper::Dumper($res);
         die "Manager lib does not return a 200 code, aborting";
     }
-    my $href = from_json( $res->[2]->[0], { allow_nonref => 1 } )
-      or die 'Response is not JSON';
+    my $href = from_json( $res->[2]->[0] ) or die 'Response is not JSON';
     return $href;
 }
 
 sub jsonPostResponse {
     my ( $self, $path, $query, $body, $type, $len ) = @_;
     my $res = $self->_post( $path, $query, $body, $type, $len )
-      or die "Manager lib has refused my post, aborting";
+      or die "PSGI lib has refused my post, aborting";
     unless ( $res->[0] == 200 ) {
         require Data::Dumper;
         print STDERR "Result dump :\n" . Data::Dumper::Dumper($res);
         die "Manager lib does not return a 200 code, aborting";
     }
-    my $href = from_json( $res->[2]->[0], { allow_nonref => 1 } )
-      or die 'Response is not JSON';
+    my $href = from_json( $res->[2]->[0] ) or die 'Response is not JSON';
     return $href;
 }
 
 sub jsonPutResponse {
     my ( $self, $path, $query, $body, $type, $len ) = @_;
     my $res = $self->_put( $path, $query, $body, $type, $len )
-      or die "Manager lib has refused my put, aborting";
+      or die "PSGI lib has refused my put, aborting";
     unless ( $res->[0] == 200 ) {
         require Data::Dumper;
         print STDERR "Result dump :\n" . Data::Dumper::Dumper($res);
         die "Manager lib does not return a 200 code, aborting";
     }
-    my $href = from_json( $res->[2]->[0], { allow_nonref => 1 } )
-      or die 'Response is not JSON';
+    my $href = from_json( $res->[2]->[0] ) or die 'Response is not JSON';
     return $href;
 }
 
