@@ -4,7 +4,7 @@ use strict;
 use Exporter 'import';
 
 use base qw(Exporter);
-our $VERSION = '1.9.0';
+our $VERSION = '1.9.99_02';
 
 # CONSTANTS
 
@@ -15,7 +15,6 @@ use constant {
     NOTICE => 1,
     ERROR  => 0,
 };
-our $no = qr/^(?:off|no|0)?$/i;
 
 our %EXPORT_TAGS = ( 'all' => [qw(DEBUG INFO WARN ERROR $no)] );
 our @EXPORT_OK   = ( @{ $EXPORT_TAGS{'all'} } );
