@@ -6,7 +6,7 @@
 
 package Lemonldap::NG::Common::Session;
 
-our $VERSION = '1.9.1';
+our $VERSION = '1.9.99_02';
 
 use Mouse;
 use Lemonldap::NG::Common::Apache::Session;
@@ -28,8 +28,9 @@ has 'kind' => (
 );
 
 has 'data' => (
-    is  => 'rw',
-    isa => 'HashRef',
+    is      => 'rw',
+    isa     => 'HashRef',
+    default => sub { {} },
 );
 
 has 'options' => (
@@ -63,8 +64,10 @@ has 'error' => (
     isa => 'Str|Undef',
 );
 
+has info => ( is => 'rw' );
+
 sub BUILD {
-    my $self = shift;
+    my ($self) = @_;
 
     # Load Apache::Session module
     unless ( $self->storageModule->can('populate') ) {
@@ -106,6 +109,14 @@ sub BUILD {
         $data->{_session_kind} = $self->kind;
     }
 
+    if ( $self->{info} ) {
+        foreach ( keys %{ $self->{info} } ) {
+            $data->{$_} = $self->{info}->{$_}
+              if ( defined $self->{info}->{$_} );
+        }
+        delete $self->{info};
+    }
+
     # Load session data into object
     if ($data) {
         $self->_save_data($data);
@@ -117,15 +128,14 @@ sub BUILD {
 }
 
 sub _tie_session {
-    my $self = shift;
-    my $options = shift || {};
+    my $self = $_[0];
+    my $options = $_[1] || {};
 
     my %h;
 
     eval {
-        # SOAP session module must be directly tied
-        if ( $self->storageModule =~
-            /Lemonldap::NG::Common::Apache::Session::SOAP/ )
+        # SOAP/REST session module must be directly tied
+        if ( $self->storageModule =~ /^Lemonldap::NG::Common::Apache::Session/ )
         {
             tie %h, $self->storageModule, $self->id,
               { %{ $self->options }, %$options };
@@ -154,9 +164,7 @@ sub _save_data {
 }
 
 sub update {
-    my $self       = shift;
-    my $infos      = shift;
-    my $tieOptions = shift;
+    my ( $self, $infos, $tieOptions ) = @_;
 
     unless ( ref $infos eq "HASH" ) {
         $self->error("You need to provide a HASHREF");
@@ -186,8 +194,7 @@ sub update {
 }
 
 sub remove {
-    my $self       = shift;
-    my $tieOptions = shift;
+    my ( $self, $tieOptions ) = @_;
 
     my $data = $self->_tie_session($tieOptions);
 
